@@ -741,7 +741,7 @@ panel.average <-
              lty = reference.line$lty,
              col,
              col.line = reference.line$col,
-             type,
+             type = "l",
              ...)
 {
     ## FIXME: pretty sure this can be made more readable using tapply
@@ -760,7 +760,7 @@ panel.average <-
         xx <- numeric(length(yy))
         for (i in yy)
             xx[i] <- fun(x[y == vals[i]])
-        panel.lines(xx, vals[yy], col = col.line, lty = lty, lwd = lwd, ...)
+        panel.lines(xx, vals[yy], col = col.line, lty = lty, lwd = lwd, type = type, ...)
     }
     else
     {
@@ -769,7 +769,7 @@ panel.average <-
         yy <- numeric(length(xx))
         for (i in xx)
             yy[i] <- fun(y[x == vals[i]])
-        panel.lines(vals[xx], yy, col = col.line, lty = lty, lwd = lwd, ...)
+        panel.lines(vals[xx], yy, col = col.line, lty = lty, lwd = lwd, type = type, ...)
      }
 }
 
